@@ -55,6 +55,7 @@ class VideoVariable(Variable):
         ('amdgpu', _("AMD AMDGPU (amdgpu)")),
         ('fglrx', _("AMD Catalyst (fglrx)")),
         ('intel', _("Intel (intel)")),
+        ('modesetting', _("Framebuffer device (modesetting)")),
         ('nouveau', _("Nvidia Nouveau (nouveau)")),
         ('nvidia', _("Nvidia Graphics Driver (nvidia)")),
         ('vesa', _("Generic VESA (vesa)")),
@@ -161,7 +162,9 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
     type = "list"
     # supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
-    supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
+    supported = ["nvidia", "fglrx", "amdgpu",
+                 "modesetting",
+                 "nouveau", "intel", "radeon"]
 
     def get(self):
         image = self.Get('cl_image')
@@ -187,7 +190,7 @@ class VariableOsX11KmsVideoDrv(ReadonlyVariable):
     Список KMS драйверов
     """
     type = "list"
-    value = ["radeon", "intel", "nouveau", "amdgpu"]
+    value = ["radeon", "intel", "nouveau", "amdgpu", "modesetting"]
 
 
 class VariableOsInstallX11VideoDrv(VideoVariable):
@@ -310,6 +313,7 @@ class VariableOsInstallX11Composite(VideoVariable):
     def get(self):
         """On/off composite"""
         defaultCompositeOn = ("nvidia", "intel", "fglrx",  "amdgpu",
+                              "modesetting",
                               "nouveau", "radeon", "default")
         composite = getValueFromCmdLine(CmdlineParams.Calculate,
                                         CmdlineParams.Composite)
